==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiWidgets/QStyleOptionHeaderV2_shell.cpp <==
#include "QStyleOptionHeaderV2_shell.h"
#include <QtJambi/Cast>

void deleter_QStyleOptionHeaderV2(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStyleOptionHeaderV2")
    QStyleOptionHeaderV2 *_ptr = reinterpret_cast<QStyleOptionHeaderV2 *>(ptr);
    if(isShell){
        delete static_cast<QStyleOptionHeaderV2_shell*>(_ptr);
    }else{
        QtJambiAPI::registerNonShellDeletion(ptr);
        delete _ptr;
    }
}

QtJambiShell* QStyleOptionHeaderV2_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QStyleOptionHeaderV2_shell) ); }

jmethodID QStyleOptionHeaderV2_shell::__shell_javaMethod(int pos) const { return QStyleOptionHeaderV2_shell::__shell()->javaMethod(typeid(QStyleOptionHeaderV2), pos); }

// emitting (writeShellConstructor)
QStyleOptionHeaderV2_shell::QStyleOptionHeaderV2_shell()
    : QStyleOptionHeaderV2()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStyleOptionHeaderV2::QStyleOptionHeaderV2_shell()", QStyleOptionHeaderV2_shell::__shell())
    QStyleOptionHeaderV2_shell::__shell()->constructed(typeid(QStyleOptionHeaderV2));
}

QStyleOptionHeaderV2_shell::QStyleOptionHeaderV2_shell(const QStyleOptionHeaderV2& other0)
    : QStyleOptionHeaderV2(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStyleOptionHeaderV2::QStyleOptionHeaderV2_shell(const QStyleOptionHeaderV2& other0)", QStyleOptionHeaderV2_shell::__shell())
    QStyleOptionHeaderV2_shell::__shell()->constructed(typeid(QStyleOptionHeaderV2));
}

// emitting (writeShellDestructor)
QStyleOptionHeaderV2_shell::~QStyleOptionHeaderV2_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QStyleOptionHeaderV2::~QStyleOptionHeaderV2()", QStyleOptionHeaderV2_shell::__shell())
    QStyleOptionHeaderV2_shell::__shell()->destructed(typeid(QStyleOptionHeaderV2));
}

void QStyleOptionHeaderV2_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QStyleOptionHeaderV2_shell*>(ptr)->QStyleOptionHeaderV2_shell::__shell()->tryDeleteShell(typeid(QStyleOptionHeaderV2));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QStyleOptionHeaderV2()
void __qt_construct_QStyleOptionHeaderV2_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionHeaderV2()")
    Q_UNUSED(__java_arguments)
    QStyleOptionHeaderV2 *__qt_this = new(__qtjambi_ptr) QStyleOptionHeaderV2_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QStyleOptionHeaderV2(QStyleOptionHeaderV2)
void __qt_construct_QStyleOptionHeaderV2_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionHeaderV2(QStyleOptionHeaderV2)")
    jobject other0 = __java_arguments[0].l;
    const QStyleOptionHeaderV2& __qt_other0 = qtjambi_cast<const QStyleOptionHeaderV2& >(__jni_env, other0);
    QStyleOptionHeaderV2 *__qt_this = new(__qtjambi_ptr) QStyleOptionHeaderV2_shell(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QStyleOptionHeaderV2_shell
void __qt_destruct_QStyleOptionHeaderV2(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStyleOptionHeaderV2")
    reinterpret_cast<QStyleOptionHeaderV2_shell*>(ptr)->~QStyleOptionHeaderV2_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStyleOptionHeaderV2::QStyleOptionHeaderV2()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionHeaderV2_initialize_1native__Lio_qt_widgets_QStyleOptionHeaderV2_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionHeaderV2::QStyleOptionHeaderV2()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionHeaderV2_0, sizeof(QStyleOptionHeaderV2_shell), typeid(QStyleOptionHeaderV2), true, &deleter_QStyleOptionHeaderV2, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStyleOptionHeaderV2::QStyleOptionHeaderV2(QStyleOptionHeaderV2)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionHeaderV2_initialize_1native__Lio_qt_widgets_QStyleOptionHeaderV2_2Lio_qt_widgets_QStyleOptionHeaderV2_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionHeaderV2::QStyleOptionHeaderV2(QStyleOptionHeaderV2)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionHeaderV2_1, sizeof(QStyleOptionHeaderV2_shell), typeid(QStyleOptionHeaderV2), true, &deleter_QStyleOptionHeaderV2, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStyleOptionHeaderV2::operator=(QStyleOptionHeaderV2)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionHeaderV2_assign_1native_1cref_1QStyleOptionHeaderV2__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QStyleOptionHeaderV2 *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionHeaderV2>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStyleOptionHeaderV2::operator=(QStyleOptionHeaderV2)", __qt_this)
        const QStyleOptionHeaderV2& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QStyleOptionHeaderV2>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionHeaderV2_setIsSectionDragTarget_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean isSectionDragTarget0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionHeaderV2 *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionHeaderV2>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->isSectionDragTarget = static_cast<bool>(isSectionDragTarget0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionHeaderV2_isSectionDragTarget_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionHeaderV2 *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionHeaderV2>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        bool  __qt_value = __qt_this->isSectionDragTarget;
        __java_return_value = jboolean(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionHeaderV2_setTextElideMode_1native_1cref_1Qt_1TextElideMode__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint textElideMode0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionHeaderV2 *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionHeaderV2>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        Qt::TextElideMode __qt_textElideMode0 = qtjambi_cast<Qt::TextElideMode>(__jni_env, textElideMode0);
        __qt_this->textElideMode = Qt::TextElideMode(__qt_textElideMode0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionHeaderV2_textElideMode_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionHeaderV2 *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionHeaderV2>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const Qt::TextElideMode&  __qt_value = __qt_this->textElideMode;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionHeaderV2_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStyleOptionHeaderV2 *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionHeaderV2>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStyleOptionHeaderV2(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStyleOptionHeaderV2>("QStyleOptionHeaderV2", "io/qt/widgets/QStyleOptionHeaderV2");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStyleOptionHeaderV2, {
        ConstructorInfo(&__qt_construct_QStyleOptionHeaderV2_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QStyleOptionHeaderV2_1, "Lio/qt/widgets/QStyleOptionHeaderV2;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStyleOptionHeaderV2);
    registerMetaType<QStyleOptionHeaderV2>("QStyleOptionHeaderV2");
    registerSizeOfShell(typeId, sizeof(QStyleOptionHeaderV2_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QStyleOptionHeader), typeId, [](void *ptr, qintptr& offset) -> bool {
            QStyleOptionHeader *object = reinterpret_cast<QStyleOptionHeader *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = object->type == QStyleOptionHeaderV2::Type && object->version == QStyleOptionHeaderV2::Version;
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeid(QStyleOption), typeId, [](void *ptr, qintptr& offset) -> bool {
            QStyleOption *object = reinterpret_cast<QStyleOption *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = object->type == QStyleOptionHeaderV2::Type && object->version == QStyleOptionHeaderV2::Version;
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiWidgets/QStyleOptionHeaderV2_shell.cpp <==
#include "QStyleOptionHeaderV2_shell.h"
#include <QtJambi/Cast>

void deleter_QStyleOptionHeaderV2(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStyleOptionHeaderV2")
    QStyleOptionHeaderV2 *_ptr = reinterpret_cast<QStyleOptionHeaderV2 *>(ptr);
    if(isShell){
        delete static_cast<QStyleOptionHeaderV2_shell*>(_ptr);
    }else{
        QtJambiAPI::registerNonShellDeletion(ptr);
        delete _ptr;
    }
}

QtJambiShell* QStyleOptionHeaderV2_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QStyleOptionHeaderV2_shell) ); }

jmethodID QStyleOptionHeaderV2_shell::__shell_javaMethod(int pos) const { return QStyleOptionHeaderV2_shell::__shell()->javaMethod(typeid(QStyleOptionHeaderV2), pos); }

// emitting (writeShellConstructor)
QStyleOptionHeaderV2_shell::QStyleOptionHeaderV2_shell()
    : QStyleOptionHeaderV2()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStyleOptionHeaderV2::QStyleOptionHeaderV2_shell()", QStyleOptionHeaderV2_shell::__shell())
    QStyleOptionHeaderV2_shell::__shell()->constructed(typeid(QStyleOptionHeaderV2));
}

QStyleOptionHeaderV2_shell::QStyleOptionHeaderV2_shell(const QStyleOptionHeaderV2& other0)
    : QStyleOptionHeaderV2(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStyleOptionHeaderV2::QStyleOptionHeaderV2_shell(const QStyleOptionHeaderV2& other0)", QStyleOptionHeaderV2_shell::__shell())
    QStyleOptionHeaderV2_shell::__shell()->constructed(typeid(QStyleOptionHeaderV2));
}

// emitting (writeShellDestructor)
QStyleOptionHeaderV2_shell::~QStyleOptionHeaderV2_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QStyleOptionHeaderV2::~QStyleOptionHeaderV2()", QStyleOptionHeaderV2_shell::__shell())
    QStyleOptionHeaderV2_shell::__shell()->destructed(typeid(QStyleOptionHeaderV2));
}

void QStyleOptionHeaderV2_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QStyleOptionHeaderV2_shell*>(ptr)->QStyleOptionHeaderV2_shell::__shell()->tryDeleteShell(typeid(QStyleOptionHeaderV2));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QStyleOptionHeaderV2()
void __qt_construct_QStyleOptionHeaderV2(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionHeaderV2()")
    Q_UNUSED(__java_arguments)
    QStyleOptionHeaderV2 *__qt_this = new(__qtjambi_ptr) QStyleOptionHeaderV2_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QStyleOptionHeaderV2::QStyleOptionHeaderV2()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionHeaderV2_initialize_1native__Lio_qt_widgets_QStyleOptionHeaderV2_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionHeaderV2::QStyleOptionHeaderV2()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionHeaderV2, sizeof(QStyleOptionHeaderV2_shell), typeid(QStyleOptionHeaderV2), true, &deleter_QStyleOptionHeaderV2, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QStyleOptionHeaderV2(QStyleOptionHeaderV2)
void __qt_construct_QStyleOptionHeaderV2_cref_QStyleOptionHeaderV2(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionHeaderV2(QStyleOptionHeaderV2)")
    jobject other0 = __java_arguments[0].l;
    const QStyleOptionHeaderV2& __qt_other0 = qtjambi_cast<const QStyleOptionHeaderV2& >(__jni_env, other0);
    QStyleOptionHeaderV2 *__qt_this = new(__qtjambi_ptr) QStyleOptionHeaderV2_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QStyleOptionHeaderV2::QStyleOptionHeaderV2(QStyleOptionHeaderV2)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionHeaderV2_initialize_1native__Lio_qt_widgets_QStyleOptionHeaderV2_2Lio_qt_widgets_QStyleOptionHeaderV2_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionHeaderV2::QStyleOptionHeaderV2(QStyleOptionHeaderV2)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionHeaderV2_cref_QStyleOptionHeaderV2, sizeof(QStyleOptionHeaderV2_shell), typeid(QStyleOptionHeaderV2), true, &deleter_QStyleOptionHeaderV2, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QStyleOptionHeaderV2_shell
void __qt_destruct_QStyleOptionHeaderV2(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStyleOptionHeaderV2")
    reinterpret_cast<QStyleOptionHeaderV2_shell*>(ptr)->~QStyleOptionHeaderV2_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStyleOptionHeaderV2::operator=(QStyleOptionHeaderV2)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionHeaderV2_assign_1native_1cref_1QStyleOptionHeaderV2__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QStyleOptionHeaderV2 *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionHeaderV2>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStyleOptionHeaderV2::operator=(QStyleOptionHeaderV2)", __qt_this)
        const QStyleOptionHeaderV2& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QStyleOptionHeaderV2>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionHeaderV2_setIsSectionDragTarget_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean isSectionDragTarget0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionHeaderV2 *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionHeaderV2>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->isSectionDragTarget = static_cast<bool>(isSectionDragTarget0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionHeaderV2_isSectionDragTarget_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionHeaderV2 *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionHeaderV2>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        bool  __qt_value = __qt_this->isSectionDragTarget;
        __java_return_value = jboolean(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionHeaderV2_setTextElideMode_1native_1cref_1Qt_1TextElideMode__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint textElideMode0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionHeaderV2 *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionHeaderV2>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        Qt::TextElideMode __qt_textElideMode0 = qtjambi_cast<Qt::TextElideMode>(__jni_env, textElideMode0);
        __qt_this->textElideMode = Qt::TextElideMode(__qt_textElideMode0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionHeaderV2_textElideMode_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionHeaderV2 *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionHeaderV2>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const Qt::TextElideMode&  __qt_value = __qt_this->textElideMode;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionHeaderV2_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStyleOptionHeaderV2 *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionHeaderV2>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStyleOptionHeaderV2(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStyleOptionHeaderV2>("QStyleOptionHeaderV2", "io/qt/widgets/QStyleOptionHeaderV2");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStyleOptionHeaderV2, {
        ConstructorInfo(&__qt_construct_QStyleOptionHeaderV2, nullptr)
       ,ConstructorInfo(&__qt_construct_QStyleOptionHeaderV2_cref_QStyleOptionHeaderV2, "Lio/qt/widgets/QStyleOptionHeaderV2;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStyleOptionHeaderV2);
    registerMetaType<QStyleOptionHeaderV2>("QStyleOptionHeaderV2");
    registerSizeOfShell(typeId, sizeof(QStyleOptionHeaderV2_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QStyleOptionHeader), typeId, [](void *ptr, qintptr& offset) -> bool {
            QStyleOptionHeader *object = reinterpret_cast<QStyleOptionHeader *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = object->type == QStyleOptionHeaderV2::Type && object->version == QStyleOptionHeaderV2::Version;
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeid(QStyleOption), typeId, [](void *ptr, qintptr& offset) -> bool {
            QStyleOption *object = reinterpret_cast<QStyleOption *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = object->type == QStyleOptionHeaderV2::Type && object->version == QStyleOptionHeaderV2::Version;
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
